package helper

import (
	"errors"
	"github.com/astaxie/beego/orm"
	"im-microservice/db"
	"im-microservice/validator_struct"
)

const (
	b_table_name = "im_base"
	b_user_id    = "company_user_id"
	b_type       = "multidevice_type"
	b_url        = "msg_hook_url"
)

func GetImBaseByUserId(user_id int64) (db.ImBase, error) {
	var im_base db.ImBase
	err := db.MysqlClient.QueryTable(b_table_name).Filter(b_user_id, user_id).One(&im_base)
	if err != nil {
		return im_base, err
	}
	return im_base, nil
}

func AddImBase(im *validator_struct.ConfigureAddStruct) error {
	configure := new(db.ImBase)
	configure.CompanyUserId = im.CompanyUserId
	configure.MsgHookUrl = im.MsgHookUrl
	configure.MultideviceType = im.MultideviceType
	if _, err := db.MysqlClient.Insert(configure); err != nil {
		return err
	}
	return nil
}

func DelConfigure(user_id int64) error {
	configure := new(db.ImBase)
	configure.CompanyUserId = user_id
	if _, err := db.MysqlClient.Delete(configure); err != nil {
		return err
	}
	return nil
}

func GetConfigureAll() []*db.ImBase{
	var configurs []*db.ImBase
	_, _ = db.MysqlClient.QueryTable(b_table_name).All(&configurs)
	return configurs
}

func UpdateConfiguer(im *validator_struct.ConfigureUpdateStruct ) error {
	orm_params := make(orm.Params)
	if im.MsgHookUrl != "" {
		orm_params["msg_hook_url"] = im.MsgHookUrl
	}
	if im.MultideviceType != 0 {
		orm_params["multidevice_type"] = im.MultideviceType
	}
	if len(orm_params)  == 0 {
		return errors.New("没有数据更改")
	}
	_, err := db.MysqlClient.QueryTable(b_table_name).Filter(b_user_id, im.CompanyUserId).Update(orm_params)
	if err != nil {
		return err
	}
	return nil
}